@@ -1,13 +1,13 @@
 #' Returns information on the number of parameters of a each type.
 #'
 #' @template arg_parset
-#' @return [\code{list}]
+#' @return [`list`]
 #'  Named list which contains for each supported parameter type the
 #'  number of parameters of this type in the given ParamSet.
 #' @export
 getParamTypeCounts = function(par.set) {
   assertClass(par.set, "ParamSet")
-  supported.types = getSupportedParamTypes()
+  supported.types = getTypeStringsAll()
   par.types = getParamTypes(par.set)
   count = lapply(supported.types, function(type) {
     sum(par.types == type)
@@ -15,15 +15,3 @@ getParamTypeCounts = function(par.set) {
   names(count) = supported.types
   return(count)
 }
-
-# Returns a vector of supported parameter types.
-getSupportedParamTypes = function() {
-  return(
-    c("numeric", "numericvector",
-      "integer", "integervector",
-      "discrete", "discretevector",
-      "logical", "logicalvector",
-      "character", "charactervector",
-      "function",
-      "untyped"))
-}
